#
# spec file for package msgpack
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           msgpack
Version:        1.4.1
Release:        3.1
Summary:        Efficient object serialization library for cross-language communication
License:        Apache-2.0
Group:          Development/Libraries/C and C++
Url:            https://msgpack.org
Source0:        https://github.com/msgpack/msgpack-c/releases/download/cpp-%{version}/%{name}-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  pkg-config

%description
MessagePack is a binary-based efficient object serialization library. It
enables to exchange structured objects between many languages like JSON.
But unlike JSON, it is very fast and small.

%package -n libmsgpackc2
Summary:        Efficient object serialization library for cross-language communication
Group:          System/Libraries

%description -n libmsgpackc2
MessagePack is a binary-based efficient object serialization library. It
enables to exchange structured objects between many languages like JSON.
But unlike JSON, it is very fast and small.

%package devel
Summary:        Development headers for libmsgpack C library
Group:          Development/Libraries/C and C++
Requires:       libmsgpackc2 = %{version}
Provides:       libmsgpack-devel = %{version}
Provides:       libmsgpackc-devel = %{version}

%description devel
MessagePack is a binary-based efficient object serialization library. It
enables to exchange structured objects between many languages like JSON.
But unlike JSON, it is very fast and small.

This package provides headers and other devel files

%prep
%setup -q

%build
%configure --disable-static
make %{?_smp_mflags}

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libmsgpackc2 -p /sbin/ldconfig
%postun -n libmsgpackc2 -p /sbin/ldconfig

%files -n libmsgpackc2
%defattr(-,root,root)
%doc COPYING NOTICE README.md
%{_libdir}/libmsgpackc.so.*

%files devel
%defattr(-,root,root)
%{_libdir}/libmsgpackc.so
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/msgpack.h
%{_includedir}/msgpack.hpp
%{_includedir}/%{name}

%changelog
* Fri Apr  1 2016 mpluskal@suse.com
- Update to 1.4.1
  * Fix TARGET_OS_IPHONE checking (#436, #438)
  * Fix invalid front() call for empty container (#435. #437)
  * Fix compile error on g++6 (C++11 only) (#426, #428)
  * Fix zone size expansion logic (#423, #427)
- Changes for 1.4.0
  * Improve documents (#387, #407)
  * Remove C++ version library (#394, #402)
  * Add Doxyfile and ChangeLog to the distribution package (#397)
  * Add signed/unsigned char test to travis-ci (#398)
  * Remove some warnings (#400, #401, #409)
  * Fix endian checking. (#404)
* Wed Dec  2 2015 ronisbr@gmail.com
- Version bump to 1.3.0.
- Changelog between v0.5.9 and v1.3.0:
  - Version 1.0.0
  * No changelog available.
  - Version 1.0.1
  * This is a maintenance release and it includes following
  * fixes:
  - Fix compilation error on Mac 10.9 (#244)
  - Fix typos in documents (#240)
  - Update CHANGELOG.md for version 1.0.0 (#242)
  - Fix erb templates for the next code generation (#239)
  - Version 1.1.0
  * Breaking changes:
  - Remove msgpack_fwd.hpp (#262)
  - Improve user types adaptation mechanism (#262)
    Since version 1.0.0, users need to obey the correct
    include order. However, it is very difficult to
    maintain the correct order in big projects. version
    1.1.0 removed this order. Users don't need to care
    about include order. Migration guide from 1.0.x to
    1.1.0 has been written. See
    https://github.com/msgpack/msgpack-c/wiki
  * Other updates:
  - Fix vector size check (#251)
  - Fix inttypes.h inclusion on MSVC (#257)
  - Support documents generation by Doxygen (#259)
  - Remove C99 style variable declaration (#253)
  - Improve documents
    (https://github.com/msgpack/msgpack-c/wiki)
  - Version 1.2.0
  * Breaking changes:
  - Change std::vector and std::array mapped to BIN
    instead of ARRAY (#243)
  - Remove redundant copy (#285)
  * Other changes:
  - Add array_ref to map to ARRAY (#243)
  - Add variant type and adaptor (#349)
  - Add object::convert_if_not_nil() (#357)
  - Fix invalid offset update (#354)
  - Add C++11 support on MSVC2015(#339, #347)
  - Fix and Improve build system (#346, #350, #361, #363)
  - Import Boost.Preprocessor as a part of msgpack-c
    (#312)
  - Fix OSX with libc++ specific errors (#334, #362)
  - Add customized containers support (#330)
  - Add std::unique_ptr and std::shared_ptr support
    (#329)
  - Add missing install files (#328)
  - Add shared/static library switching option (#316)
  - Improve no throw description on C++11 (#313)
  - Import Boost.Predef as a part of msgpack-c (#312)
  - Add map based serialize support (#306)
  - Add Boost.Fusion support (#305)
  - Add v4 format RAW support (#304)
  - Fix zbuffer with empty string problem (#303)
  - Add non default constructible class support (#302,
    [#324], #327, #331, #332, #345)
  - Add inline keyword to function (template) (#299)
  - Add EXT type supporting classes (#292, #308)
  - Fix raw_ref != comparison (#290)
  - Add object deep copy (#288)
  - Remove some warnings (#284, #322, #323, #335)
  - Improve compiler version checking (#283)
  - Add return value to object::convert() (#282)
  - Improve move semantic support in C++11 (#279, #353)
  - Add Boost.StringRef support (#278)
  - Improve CI environment (#276, #294, #338)
  - Add converting to JSON (#274, #301)
  - Fix iOS specific problem (#270)
  - Improve doxtgen document generation (#269)
  - Add Boost.Optional support (#268)
  - Fix msvc specific problem (#267, #295)
  - Add base class serialization. (#265, #277)
  - Add and improve examples. (#264, #310, #311, #341,
    [#342], #344)
  - Fix wiki URL. (#263)
  - Version 1.3.0
  * Change the license from the Apache License Version 2.0 to
    the Boost Software License, Version 1.0.(#386)
  * Remove some warnings (#365)
  * Add std::reference_wrapper support(#373, #384)
  * Improve tests (#375, #378, #379, #380)
  * Fix msvc specific problem (#376, #383)
  * Fix typos (#381)
* Mon Mar  2 2015 tchvatal@suse.com
- Spec-cleaner (just kill few small empty comment lines)
* Thu Aug 14 2014 idonmez@suse.com
- Update to version 0.5.9
  * Support std::tr1 unordered containers by default
  * Crash fixes
  * Add FILE* buffer
* Tue Feb 11 2014 jengelh@inai.de
- Don't even build static libraries if they are going to be removed
  again.
- Remove redundant build dependencies that are not used
* Mon Feb 10 2014 asn@cryptomilk.org
- Big bang!
